pub struct MultiInsert<DP, T, S>where
DP: DataProvider,{ /* private fields */ }Expand description
A built-in helper for benchmarking multi-insert.
This is intended to be used in conjunction with crate::build::build and crate::build::build_tracked.
Notes
The multi-insert API for diskann::graph::DiskANNIndex parallelizes insertion internally. When using
crate::build::build, users should use crate::build::Parallelism::sequential.
Implementations
Sourceimpl<DP, T, S> MultiInsert<DP, T, S>where
DP: DataProvider,
impl<DP, T, S> MultiInsert<DP, T, S>where
DP: DataProvider,
Sourcepub fn new<I>(
index: Arc<DiskANNIndex<DP>>,
data: Arc<Matrix<T>>,
strategy: S,
to_id: I,
) -> Arc<Self>where
I: ToId<DP::ExternalId>,
pub fn new<I>(
index: Arc<DiskANNIndex<DP>>,
data: Arc<Matrix<T>>,
strategy: S,
to_id: I,
) -> Arc<Self>where
I: ToId<DP::ExternalId>,
Construct a new MultiInsert builder for the given index.
Vectors will be inserted using all rows of data with strategy used
for the diskann::graph::glue::InsertStrategy.
Parameter to_id will be used to convert row indices of data (0..data.nrows())
to external IDs.