pub struct Identity<T>(/* private fields */);Expand description
A ToId implementation that treats the implicit index as the external ID.
This requires that the external ID type T can be constructed from a usize.
Implementations