Slice

Struct Slice 

pub struct Slice<T>(/* private fields */);
An implementation of ToId and ToIdSized that encodes external IDs as a slice.

use diskann_benchmark_core::build::ids::{Slice, ToId, ToIdSized};

let slice = Slice::new([10u32, 20, 30].into());
assert_eq!(slice.len(), 3);
assert_eq!(slice.to_id(0).unwrap(), 10);
assert_eq!(slice.to_id(1).unwrap(), 20);
assert_eq!(slice.to_id(2).unwrap(), 30);
assert!(slice.to_id(3).is_err());

Implementations

Source

impl<T> Slice<T>

pub fn new(slice: Box<[T]>) -> Self

Construct a new Slice from the given boxed slice.

The contents of the Slice will be identical to the provided box.