pub enum IdCount {
Fixed(NonZeroUsize),
Dynamic(Option<NonZeroUsize>),
}Expand description
Indicate whether the number of items returned from search are bounded by a fixed amount or can grow to an unknown size.
Variants
Fixed(NonZeroUsize)
The number of ids returned from search are known to be bounded.
Dynamic(Option<NonZeroUsize>)
The number of ids returned from search is unknown or unbounded. A size hint can be provided that can potentially improve performance.