MultiHop

Struct MultiHop 

pub struct MultiHop<DP, T, S>
where DP: DataProvider,
{ /* private fields */ }
A built-in helper for benchmarking filtered K-nearest neighbors search using the multi-hop search method.

This is intended to be used in conjunction with search::search or search::search_all and provides some basic additional metrics for the latter. Result aggregation for search::search_all is provided by the search::graph::knn::Aggregator type (same aggregator as search::graph::knn::KNN).

The provided implementation of Search accepts graph::search::Knn and returns search::graph::knn::Metrics as additional output.

Implementations

Source

impl<DP, T, S> MultiHop<DP, T, S>
where DP: DataProvider,

pub fn new( index: Arc<DiskANNIndex<DP>>, queries: Arc<Matrix<T>>, strategy: Strategy<S>, labels: Arc<[Arc<dyn QueryLabelProvider<DP::InternalId>>]>, ) -> Result<Arc<Self>>

Construct a new MultiHop searcher.

If strategy is one of the container variants of Strategy, its length must match the number of rows in queries. If this is the case, then the strategies will have a querywise correspondence (see search::SearchResults) with the query matrix.

Additionally, the length of labels must match the number of rows in queries and will be used in querywise correspondence with queries.

Errors

Returns an error under the following conditions.

  1. The number of elements in strategy is not compatible with the number of rows in queries.

  2. The number of label providers in labels is not equal to the number of rows in queries.