pub struct Aggregator<'a, I> { /* private fields */ }Expand description
A search::Aggregate for collecting the results of multiple Range search runs.
In addition to collecting latencies and other metrics, this aggregator computes
crate::recall::AveragePrecisionMetrics using a provided groundtruth.
The aggregated results are available as a Summary.
Implementations
Sourceimpl<'a, I> Aggregator<'a, I>
impl<'a, I> Aggregator<'a, I>
Sourcepub fn new(groundtruth: &'a dyn Rows<I>) -> Self
pub fn new(groundtruth: &'a dyn Rows<I>) -> Self
Construct a new Aggregator using groundtruth for average precision computation.