ResultIds

Struct ResultIds 

pub struct ResultIds<I> { /* private fields */ }
A generic wrapper for containing the results IDs for multiple query searches.

Users should interact with this type via the as_rows methods.

Note that the slices returned by as_rows may have different lengths depending on how many IDs were actually returned for each query.

Implementations

Source

impl<I> ResultIds<I>

pub fn as_rows(&self) -> &dyn Rows<I>

Return the contained IDs as a recall::Rows<I>.