Run

Struct Run 

pub struct Run<P> { /* private fields */ }
A single run of search containing a Setup and Search::Parameters.

Implementations

Source

impl<P> Run<P>

pub fn new(parameters: P, setup: Setup) -> Self

Construct a new Run around the search parameters and setup.

pub fn parameters(&self) -> &P

Return a reference to the contained search parameters.

pub fn setup(&self) -> &Setup

Return a reference to the contained setup.