SearchResults

Struct SearchResults 

pub struct SearchResults<I, T> { /* private fields */ }
Aggregated results for a single invocation of search. This corresponds to a potentially parallelized batch of queries.

Note

In the documentation of the member functions, the term “querywise” describes that the returned collection has an ordered correspondence with the original queries.

If the Search object that generated these results as N queries (as returned by Search::num_queries), then for these returned container, entry i will correspond to the ith query for i in 0..N.

Implementations

Source

impl<I, T> SearchResults<I, T>

pub fn len(&self) -> usize

Return the number of queries in the batch.

pub fn is_empty(&self) -> bool

Return true only if self.len() == 0.

pub fn end_to_end_latency(&self) -> MicroSeconds

Return the wall clock time taken to process all queries in the batch.

pub fn ids(&self) -> &ResultIds<I>

Return the querywise computed IDs from search.

pub fn latencies(&self) -> &[MicroSeconds]

Return the querywise latencies for each search. If Self::latencies_mut has been called, the return slice loses its querywise guarantee.

pub fn latencies_mut(&mut self) -> &mut [MicroSeconds]

Return the querywise latencies for each search by mutable reference. This is for efficient use of diskann_benchmark_runner::utils::percentiles::compute_percentiles.

Modifying the underlying slice invalidates the querywise guarantee.

pub fn output(&self) -> &[T]

Return the querywise customized outputs from search.

pub fn take_output(self) -> Vec<T>

Consume self, returning the querywise customized outputs from search by value.