Aggregate

Trait Aggregate 

pub trait Aggregate<P, I, O> {
    type Output;

    // Required method
    fn aggregate(
        &mut self,
        run: Run<P>,
        results: Vec<SearchResults<I, O>>,
    ) -> Result<Self::Output>;
}
Aggregate search results from multiple repetitions of a single run in search_all.

Type Parameters

Required Associated Types

type Output

The type of the aggregated result.

Required Methods

fn aggregate( &mut self, run: Run<P>, results: Vec<SearchResults<I, O>>, ) -> Result<Self::Output>

Aggregate the results for all repetitions of run.

The length of results is guaranteed to be equal to Run::setup().reps.

Implementors

Source

impl<I> Aggregate<Knn, I, Metrics> for diskann_benchmark_core::search::graph::knn::Aggregator<'_, I>

Source

impl<I> Aggregate<Range, I, Metrics> for diskann_benchmark_core::search::graph::range::Aggregator<'_, I>