DropDeleted

Struct DropDeleted 

pub struct DropDeleted<DP>
where DP: DataProvider,
{ /* private fields */ }
A Build stage that invokes drop_deleted_neighbors
on a collection of points.

The collection of points is determined by an implementation of ToIdSized.

Implementations

Source

impl<DP> DropDeleted<DP>
where DP: DataProvider,

pub fn new( index: Arc<DiskANNIndex<DP>>, only_orphans: bool, to_id: impl ToIdSized<DP::InternalId> + 'static, ) -> Arc<Self>

Construct a new DropDeleted build stage.

This Build object will run for all Ids provided by to_id, invoking diskann::graph::DiskANNIndex::drop_deleted_neighbors on each ID.

Argument only_orphans is passed directly to the method on diskann::graph::DiskANNIndex.

Notes

This method is a little different from other stages since it uses internal IDs rather than external IDs. As such, users are not encouraged to use it.