pub struct InplaceDelete<DP, S>where
DP: DataProvider,{ /* private fields */ }Expand description
A built-in helper for running and benchmarking
inplace_delete.
This is intended to be used in conjunction with crate::build::build and
crate::build::build_tracked.
Implementations
Sourceimpl<DP, S> InplaceDelete<DP, S>where
DP: DataProvider,
impl<DP, S> InplaceDelete<DP, S>where
DP: DataProvider,
Sourcepub fn new(
index: Arc<DiskANNIndex<DP>>,
strategy: S,
num_to_replace: usize,
inplace_delete_method: InplaceDeleteMethod,
to_id: impl ToIdSized<DP::ExternalId> + 'static,
) -> Arc<Self>
pub fn new( index: Arc<DiskANNIndex<DP>>, strategy: S, num_to_replace: usize, inplace_delete_method: InplaceDeleteMethod, to_id: impl ToIdSized<DP::ExternalId> + 'static, ) -> Arc<Self>
Construct a new InplaceDelete build stage.
This Build object will run for all Ids provided by to_id, invoking
diskann::graph::DiskANNIndex::inplace_delete on each ID.
Arguments num_to_replace and inplace_delete_method are passed directly to the method
on diskann::graph::DiskANNIndex.