AnyStream

Struct AnyStream 

pub struct AnyStream<'a, T>(/* private fields */);
A type-erased Stream implementation that wraps stream (outputs)Stream::Output in Box<dyn Any>.

This is useful as the final layer in a stack of nested Streams that allows the top level Executor to operate without knowledge of the concrete output types.

From a performance perspective, this is usually fine since

  1. Individual Stream operations are typically expensive relative to the cost of boxing.
  2. Many concrete Stream implementations will use the same Executor implementation. Thus, boxing can help reduce code bloat without significant performance impact.

Implementations

Source

impl<'a, T> AnyStream<'a, T>

pub fn new(stream: &'a mut T) -> Self

Wrap stream in an AnyStream.