pub fn average_all<I>(x: I) -> f64where
I: IntoIterator<Item: AsF64Lossy>,Expand description
Computes the arithmetic mean of an iterator of values, returning 0.0 when empty.
pub fn average_all<I>(x: I) -> f64where
I: IntoIterator<Item: AsF64Lossy>,Computes the arithmetic mean of an iterator of values, returning 0.0 when empty.