Identity

Struct Identity 

pub struct Identity<T>(/* private fields */);
A ToId implementation that treats the implicit index as the external ID.

This requires that the external ID type T can be constructed from a usize.

Implementations

Source

impl<T> Identity<T>

pub fn new() -> Self

Construct a new Identity.