#[non_exhaustive]pub struct BatchResult<T> {
pub taskid: usize,
pub batch: Range<usize>,
pub latency: MicroSeconds,
pub output: T,
}Expand description
The results of processing a single batch during build.
This struct is marked as #[non_exhaustive] to allow for future extension.
See: BuildResults, build and build_tracked.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.taskid: usizeThe index of the task that executed this batch. This will be in the range 0..ntasks where
ntasks is the number of tasks specified to build.
batch: Range<usize>The range of data points processed by this batch.
latency: MicroSecondsThe wall clock time taken to process this batch.
output: TThe customized Build::Output for this batch.
Implementations