pub trait AsProgress {
// Required method
fn as_progress(&self, max: usize) -> Arc<dyn Progress>;
}Expand description
Enable lazy creation of a progress reporter for the long running build operation.
See: Progress.
Required Methods
Sourcefn as_progress(&self, max: usize) -> Arc<dyn Progress>
fn as_progress(&self, max: usize) -> Arc<dyn Progress>
Construct a progress reporter for an operation consisting of max points.