pub struct MultiHop<DP, T, S>where
DP: DataProvider,{ /* private fields */ }Expand description
A built-in helper for benchmarking filtered K-nearest neighbors search using the multi-hop search method.
This is intended to be used in conjunction with search::search or search::search_all
and provides some basic additional metrics for the latter. Result aggregation for
search::search_all is provided by the search::graph::knn::Aggregator type (same
aggregator as search::graph::knn::KNN).
The provided implementation of Search accepts graph::search::Knn
and returns search::graph::knn::Metrics as additional output.
Implementations
Sourceimpl<DP, T, S> MultiHop<DP, T, S>where
DP: DataProvider,
impl<DP, T, S> MultiHop<DP, T, S>where
DP: DataProvider,
Sourcepub fn new(
index: Arc<DiskANNIndex<DP>>,
queries: Arc<Matrix<T>>,
strategy: Strategy<S>,
labels: Arc<[Arc<dyn QueryLabelProvider<DP::InternalId>>]>,
) -> Result<Arc<Self>>
pub fn new( index: Arc<DiskANNIndex<DP>>, queries: Arc<Matrix<T>>, strategy: Strategy<S>, labels: Arc<[Arc<dyn QueryLabelProvider<DP::InternalId>>]>, ) -> Result<Arc<Self>>
Construct a new MultiHop searcher.
If strategy is one of the container variants of Strategy, its length
must match the number of rows in queries. If this is the case, then the
strategies will have a querywise correspondence (see search::SearchResults)
with the query matrix.
Additionally, the length of labels must match the number of rows in queries
and will be used in querywise correspondence with queries.
Errors
Returns an error under the following conditions.
-
The number of elements in
strategyis not compatible with the number of rows inqueries. -
The number of label providers in
labelsis not equal to the number of rows inqueries.