pub struct Range<DP, T, S>where
DP: DataProvider,{ /* private fields */ }Expand description
A built-in helper for benchmarking the range search method
[graph::DiskANNIndex::range_search].
This is intended to be used in conjunction with search::search or
search::search_all and provides some basic additional metrics for
the latter. Result aggregation for search::search_all is provided
by the Aggregator type.
The provided implementation of Search accepts
graph::search::Range and returns Metrics as additional output.
Implementations
Sourceimpl<DP, T, S> Range<DP, T, S>where
DP: DataProvider,
impl<DP, T, S> Range<DP, T, S>where
DP: DataProvider,
Sourcepub fn new(
index: Arc<DiskANNIndex<DP>>,
queries: Arc<Matrix<T>>,
strategy: Strategy<S>,
) -> Result<Arc<Self>>
pub fn new( index: Arc<DiskANNIndex<DP>>, queries: Arc<Matrix<T>>, strategy: Strategy<S>, ) -> Result<Arc<Self>>
Construct a new Range searcher.
If strategy is one of the container variants of Strategy, its length
must match the number of rows in queries. If this is the case, then the
strategies will have a querywise correspondence (see search::SearchResults)
with the query matrix.
Errors
Returns an error if the number of elements in strategy is not compatible with
the number of rows in queries.