Summary

Struct Summary 

#[non_exhaustive]
pub struct Summary { pub setup: Setup, pub parameters: Range, pub end_to_end_latencies: Vec<MicroSeconds>, pub mean_latencies: Vec<f64>, pub p90_latencies: Vec<MicroSeconds>, pub p99_latencies: Vec<MicroSeconds>, pub average_precision: AveragePrecisionMetrics, }
An search::Aggregated summary of multiple Range search runs returned by the provided Aggregator.

This struct is marked as non-exhaustive to allow for future additions.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
setup: Setup

The search::Setup used for the batch of runs.

parameters: Range

The graph::search::Range used for the batch of runs.

end_to_end_latencies: Vec<MicroSeconds>

The end-to-end latency for each repetition in the batch.

mean_latencies: Vec<f64>

The average latency for individual queries.

This contains one entry per repetition in the batch.

p90_latencies: Vec<MicroSeconds>

The 90th percentile latency for individual queries.

This contains one entry per repetition in the batch.

p99_latencies: Vec<MicroSeconds>

The 99th percentile latency for individual queries.

This contains one entry per repetition in the batch.

average_precision: AveragePrecisionMetrics

The average precision metrics for the batch of runs.

This implementation assumes that search is deterministic and only uses the first repetition’s results to compute the average precision.