pub struct Setup {
pub threads: NonZeroUsize,
pub tasks: NonZeroUsize,
pub reps: NonZeroUsize,
}Expand description
High level parameters for configuring a search run using search_all.
Fields
threads: NonZeroUsizeThe number of threads to spawn in the tokio::runtime::Runtime.
tasks: NonZeroUsizeThe number of search tasks into which the search will be parallelized.
This is intentionally decoupled from threads to allow for oversubscription
of truly asynchronous providers.
reps: NonZeroUsizeThe number of repetitions of the search to perform.