pub struct AnyStream<'a, T>(/* private fields */);Expand description
A type-erased Stream implementation that wraps stream (outputs)Stream::Output in
Box<dyn Any>.
This is useful as the final layer in a stack of nested Streams that allows the top
level Executor to operate without knowledge of the concrete output types.
From a performance perspective, this is usually fine since
Implementations